@@ -10,6 +10,7 @@ use modmpi
 use modomp
 use modvars
 use modramdisk
+use moddelf
 implicit none
 ! local variables
 logical exist
@@ -22,10 +23,12 @@ call mpi_comm_size(mpicom,np_mpi,ierror)
 ! determine the local MPI process number
 call mpi_comm_rank(mpicom,lp_mpi,ierror)
 ! determine if the local process is the master
-if (lp_mpi.eq.0) then
+if (lp_mpi == 0) then
   mp_mpi=.true.
   write(*,*)
-  write(*,'("Elk code version ",I1.1,".",I1.1,".",I2.2," started")') version
+  write(*,'("+---------------------------------+")')
+  write(*,'("| Elk code version ",I1.1,".",I1.1,".",I2.2," started |")') version
+  write(*,'("+---------------------------------+")')
 else
   mp_mpi=.false.
 end if
@@ -35,10 +38,6 @@ call readinput
 call omp_init
 ! initialise the MKL library
 call mkl_init
-! initialise the OpenBLAS library
-call oblas_init
-! initialise the BLIS library
-call blis_init
 if (mp_mpi) then
   write(*,*)
   write(*,'("Number of MPI processes : ",I6)') np_mpi
@@ -65,7 +64,7 @@ if (mp_mpi) then
   end if
   if (wrtvars) then
 ! delete the VARIABLES.OUT file
-    call delvars
+    call delfile('VARIABLES.OUT')
 ! write version number to VARIABLES.OUT
     call writevars('version',nv=3,iva=version)
   end if
@@ -80,7 +79,7 @@ if (ramdisk) then
     write(*,'("RAM disk enabled")')
     if (.not.wrtdsk) then
       write(*,*)
-      write(*,'("Warning(elk): Some direct access files may not be written to &
+      write(*,'("Warning(elk): some direct access files may not be written to &
        &disk")')
     end if
   end if
@@ -89,21 +88,23 @@ else
 end if
 ! perform the tasks
 do itask=1,ntasks
+! synchronise MPI processes
+  call mpi_barrier(mpicom,ierror)
   task=tasks(itask)
   if (mp_mpi) then
     write(*,*)
-    write(*,'("Info(elk): current task : ",I6)') task
+    write(*,'("+-----------------------+")')
+    write(*,'("| Current task : ",I6," |")') task
+    write(*,'("+-----------------------+")')
   end if
 ! increment the batch variables if required
   if (batch) call batchdv
-! synchronise MPI processes
-  call mpi_barrier(mpicom,ierror)
 ! check if task can be run with MPI
-  if (lp_mpi.gt.0) then
-    if (any(task.eq.[0,1,2,3,5,15,16,28,29,61,62,63,110,120,121,125,135,136, &
+  if (lp_mpi > 0) then
+    if (any(task == [0,1,2,3,5,15,16,28,29,61,62,63,110,120,121,125,135,136, &
      162,170,180,185,188,200,201,205,208,240,241,270,271,300,320,330,331,350, &
-     351,371,372,373,440,460,461,462,463,471,478,600,610,620,630,640,700,701]))&
-     then
+     351,371,372,373,380,390,420,421,440,460,461,462,463,471,478,600,610,620, &
+     630,640,700,701])) then
       continue
     else
       write(*,'("Info(elk): MPI process ",I6," idle for task ",I6)') lp_mpi,task
@@ -231,8 +232,14 @@ do itask=1,ntasks
     call spiralsc
   case(371,372,373)
     call jprplot
+  case(380)
+    call piezoelt
+  case(390)
+    call magnetoelt
   case(400)
     call writetm
+  case(420,421)
+    call moldyn
   case(430)
     call writestrain
   case(440)
@@ -247,6 +254,8 @@ do itask=1,ntasks
     call bornecdyn
   case(480,481)
     call dielectric_tdrt
+  case(485)
+    call writejw
   case(500)
     call testcheck
   case(550)
@@ -281,17 +290,18 @@ do itask=1,ntasks
   call closefiles
 end do
 if (mp_mpi) then
-  open(50,file='RUNNING')
-  close(50,status='DELETE')
+  call delfile('RUNNING')
   write(*,*)
-  write(*,'("Elk code stopped")')
+  write(*,'("+------------------+")')
+  write(*,'("| Elk code stopped |")')
+  write(*,'("+------------------+")')
 end if
 ! terminate MPI execution environment
 call mpi_finalize(ierror)
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 8.4.30}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 9.2.5}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -328,13 +338,13 @@ end program
 !   Kvashnin, Tristan M\"uller, Arsenii Gerasimov, Manh Duc Le, Jon Lafuente
 !   Bartolom\'{e}, Ren\'{e} Wirnata, Jagdish Kumar, Andrew Shyichuk, Nisha
 !   Singh, Pietro Bonfa, Ronald Cohen, Alyn James, Chung-Yu Wang, Leon Kerber,
-!   Yunfan Liang and Xavier Gonze. Special mention of David Singh's very useful
-!   book on the LAPW method\footnote{D. J. Singh, {\it Planewaves,
-!   Pseudopotentials and the LAPW Method} (Kluwer Academic Publishers, Boston,
-!   1994).} must also be made. Finally we would like to acknowledge the generous
-!   support of Karl-Franzens-Universit\"{a}t Graz, the EU Marie-Curie Research
-!   Training Networks initiative, the Max Born Institute and the Max Planck
-!   Society.
+!   Yunfan Liang, Xavier Gonze, Mike Bruckhoff and Eddie Harris-Lee. Special
+!   mention of David Singh's very useful book on the LAPW method\footnote{D. J.
+!   Singh, {\it Planewaves, Pseudopotentials and the LAPW Method} (Kluwer
+!   Academic Publishers, Boston, 1994).} must also be made. Finally we would
+!   like to acknowledge the generous support of Karl-Franzens-Universit\"{a}t
+!   Graz, the EU Marie-Curie Research Training Networks initiative, the Max Born
+!   Institute and the Max Planck Society.
 !
 !   \vspace{24pt}
 !   Kay Dewhurst\newline
@@ -345,7 +355,7 @@ end program
 !   Hardy Gross
 !
 !   \vspace{12pt}
-!   Berlin, Halle, Jerusalem and Uppsala, May 2022
+!   Berlin, Halle, Jerusalem and Uppsala, November 2023
 !   \newpage
 !
 !   \section{Units}
@@ -360,15 +370,10 @@ end program
 !
 !   \section{Compiling and running Elk}
 !   \subsection{Compiling the code}
-!   Unpack the code from the archive file. Run the command
-!   \begin{verbatim}
-!     setup
-!   \end{verbatim}
-!   in the {\tt elk} directory and select the appropriate system and compiler.
-!   We highly recommend that you edit the file {\tt make.inc} and tune the
-!   compiler options for your computer system. In particular, use of
-!   machine-optimised BLAS/LAPACK libraries can result in significant increase
-!   in performance, but make sure they are of version $3.x$. Following this, run
+!   Unpack the code from the archive file. Edit the file {\tt make.inc} in the
+!   {\tt elk} directory and adjust the compiler options for your computer
+!   system. Use of machine-optimised BLAS/LAPACK and FFT libraries will result
+!   in significant increase in performance. Following this, run
 !   \begin{verbatim}
 !     make
 !   \end{verbatim}
@@ -704,12 +709,6 @@ end program
 !    $(0.4,0.15)$}
 !   See {\tt mixtype} and {\tt mixsdb}.
 !
-!   \block{c\_tb09}{
-!   {\tt c\_tb09} & Tran-Blaha constant $c$ & real & -}
-!   Sets the constant $c$ in the Tran-Blaha '09 functional. Normally this is
-!   calculated from the density, but there may be situations where this needs to
-!   be adjusted by hand. See {\it Phys. Rev. Lett.} {\bf 102}, 226401 (2009).
-!
 !   \block{chgexs}{
 !   {\tt chgexs} & excess electronic charge & real & $0.0$}
 !   This controls the amount of charge in the unit cell beyond that required to
@@ -744,10 +743,11 @@ end program
 !   {\tt deltast} & size of the change in lattice vectors used for calculating
 !    the stress tensor & real & $0.005$}
 !   The stress tensor is computed by changing the lattice vector matrix $A$ by
-!   $$ A\rightarrow (1+\delta t\,e_i)A, $$
-!   where $dt$ is an infinitesimal equal in practice to {\tt deltast} and $e_i$
-!   is the $i^{\rm th}$ strain tensor. Numerical finite differences are used to
-!   compute the stress tensor as the derivative of the total energy $dE_i/dt$.
+!   $$ A\rightarrow (1+\delta t\,e_k)A, $$
+!   where $\delta t$ is an infinitesimal equal in practice to {\tt deltast} and
+!   $e_k$ is the $k^{\rm th}$ strain tensor. Numerical finite differences are
+!   used to compute the stress tensor as the derivative of the total energy
+!   $dE_k/dt$.
 !
 !   \block{dft+u}{
 !   {\tt dftu} & type of DFT+$U$ calculation & integer & 0 \\
@@ -843,7 +843,7 @@ end program
 !
 !   \block{epsforce}{
 !   {\tt epsforce} & convergence tolerance for the forces during a geometry
-!    optimisation run & real & $2\times 10^{-3}$}
+!    optimisation run & real & $5\times 10^{-3}$}
 !   If the mean absolute value of the atomic forces is less than {\tt epsforce}
 !   then the geometry optimisation run is ended. See also {\tt tasks} and
 !   {\tt latvopt}.
@@ -872,7 +872,7 @@ end program
 !   \block{epsstress}{
 !   {\tt epsstress} & convergence tolerance for the stress tensor during a
 !    geometry optimisation run with lattice vector relaxation & real &
-!    $5\times 10^{-4}$}
+!    $2\times 10^{-3}$}
 !   See also {\tt epsforce} and {\tt latvopt}.
 !
 !   \block{emaxelnes}{
@@ -959,7 +959,7 @@ end program
 !    Hamiltonian & logical & {\tt .true.}}
 !
 !   \block{highq}{
-!   {\tt highq} & {\tt .true.} if a high quality parameter set should be used &
+!   {\tt highq} & {\tt .true.} if a high-quality parameter set should be used &
 !    logical & {\tt .false.}}
 !   Setting this to {\tt .true.} results in some default parameters being
 !   changed to ensure good convergence in most situations. These changes can be
@@ -1123,17 +1123,6 @@ end program
 !   specified (even for collinear calculations). See {\tt fsmtype}, {\tt taufsm}
 !   and {\tt spinpol}.
 !
-!   \block{msmooth}{
-!   {\tt msmooth} & amount of smoothing to be applied to the
-!    exchange-correlation potentials and magnetic field & integer & 0}
-!   Smoothing operations can be applied to the exchange-correlation potentials
-!   $v_{xc}$, $w_{xc}$ and the magnetic field ${\bf B}_{xc}$ in order to improve
-!   convergence. In the muffin-tin, this smoothing takes the form of $m$
-!   successive three-point running averages applied to the radial component. In
-!   the interstitial region, the potential is first Fourier transformed to
-!   $G$-space, then a low-pass filter of the form $\exp[-2m(G/G_{\rm max})^8]$
-!   is applied and the function is transformed back to real-space.
-!
 !   \block{mstar}{
 !   {\tt mstar} & value of the effective mass parameter used for adaptive
 !    determination of {\tt swidth} & real & $10.0$}
@@ -1612,16 +1601,12 @@ end program
 !   identical to that for atomic position optimisation. See {\tt tau0atp} and
 !   {\tt latvopt}.
 !
-!   \block{tauoep}{
-!   {\tt tauoep} & step length and starting fraction for the OEP iterative
-!    solver & real(2) & $(0.05, 0.95)$}
+!   \block{tau0oep}{
+!   {\tt tau0oep} & initial step length for the OEP iterative solver & real &
+!    $0.5$}
 !   The optimised effective potential is determined using an interative method
-!   [Phys. Rev. Lett. 98, 196405 (2007)]. This variable sets the step length
-!   described in the article. The second number defines the fraction of the
-!   existing potential to be used as the starting point of the iterative
-!   procedure. These parameters are also used for inverting the Kohn-Sham
-!   equations as required by the self-consistent density $GW$ method. See
-!   {\tt maxitoep}.
+!   [Phys. Rev. Lett. 98, 196405 (2007)]. This variable sets the step length as
+!   described in the article. See {\tt maxitoep}.
 !
 !   \block{taufsm}{
 !   {\tt taufsm} & the step size to be used when finding the effective magnetic
@@ -1721,7 +1706,7 @@ end program
 !   files. See also {\tt hmaxvr} and {\tt reduceh}.
 !
 !   \block{vhighq}{
-!   {\tt vhighq} & {\tt .true.} if a very high quality parameter set should be
+!   {\tt vhighq} & {\tt .true.} if a very high-quality parameter set should be
 !    used & logical & {\tt .false.}}
 !   Setting this to {\tt .true.} results in some default parameters being
 !   changed to ensure excellent convergence in most situations. See also
