@@ -26,7 +26,7 @@ call init2
 ! check q-vector is commensurate with k-point grid
 v(:)=dble(ngridk(:))*vecql(:)
 v(:)=abs(v(:)-nint(v(:)))
-if ((v(1).gt.epslat).or.(v(2).gt.epslat).or.(v(3).gt.epslat)) then
+if ((v(1) > epslat).or.(v(2) > epslat).or.(v(3) > epslat)) then
   write(*,*)
   write(*,'("Error(elnes): q-vector incommensurate with k-point grid")')
   write(*,'(" ngridk : ",3I6)') ngridk
@@ -81,7 +81,7 @@ do ik=1,nkptnr
   call genexpmat(vkl(:,ik),expmt,emat)
 ! add to the double differential scattering cross-section
   do jst=1,nstsv
-    if (evalsv(jst,jk).lt.emaxelnes) then
+    if (evalsv(jst,jk) < emaxelnes) then
       do ist=1,nstsv
         e(ist,jst,ik)=evalsv(ist,ikq)-evalsv(jst,jk)
         t1=dble(emat(ist,jst))**2+aimag(emat(ist,jst))**2
@@ -102,7 +102,7 @@ allocate(ddcs(nwplot))
 call brzint(nswplot,ngridk,nsk,ivkiknr,nwplot,wplot,n,n,e,f,ddcs)
 q=sqrt(vecqc(1)**2+vecqc(2)**2+vecqc(3)**2)
 t1=2.d0/(omega*occmax)
-if (q.gt.epslat) t1=t1/q**4
+if (q > epslat) t1=t1/q**4
 ddcs(:)=t1*ddcs(:)
 open(50,file='ELNES.OUT',form='FORMATTED')
 wd=wplot(2)-wplot(1)
