@@ -126,7 +126,7 @@ engycl=engynn+engyen+engyhar
 !-------------------------!
 !     exchange energy     !
 !-------------------------!
-if ((xctype(1).lt.0).or.(task.eq.5)) then
+if ((xctype(1) < 0).or.(task == 5)) then
 ! exact exchange for OEP-EXX or Hartree-Fock on last self-consistent loop
   if (tlast) then
     call exxengy
@@ -145,14 +145,9 @@ end if
 !----------------------------!
 !     correlation energy     !
 !----------------------------!
-if (task.eq.5) then
-  if (hybrid) then
-! fraction of DFT correlation energy for hybrid functionals
-    engyc=rfinp(rhomt,rhoir,ecmt,ecir)
-  else
+if ((task == 5).and.(.not.hybrid)) then
 ! zero correlation energy for pure Hartree-Fock
-    engyc=0.d0
-  end if
+  engyc=0.d0
 else
 ! correlation energy from the density
   engyc=rfinp(rhomt,rhoir,ecmt,ecir)
@@ -161,7 +156,7 @@ end if
 !     DFT+U energy     !
 !----------------------!
 engydu=0.d0
-if (dftu.ne.0) then
+if (dftu /= 0) then
   do idu=1,ndftu
     is=isldu(1,idu)
     do ia=1,natoms(is)
@@ -193,7 +188,7 @@ end do
 ! core electron kinetic energy
 call energykncr
 ! total electron kinetic energy
-if (task.eq.5) then
+if (task == 5) then
 ! Hartree-Fock case
   engykn=engykncr
 ! kinetic energy from valence states
@@ -224,7 +219,7 @@ else
     sm=sm+rfinp(magmt(:,:,idm),magir(:,idm),rfmt,bsir(:,idm))
   end do
 ! remove fixed tensor moment potential matrix contribution
-  if (ftmtype.ne.0) then
+  if (ftmtype /= 0) then
     n2=(lmmaxdm*nspinor)**2
     do ias=1,natmtot
       z1=zdotc(n2,dmatmt(:,:,:,:,ias),1,vmftm(:,:,:,:,ias),1)
@@ -234,19 +229,24 @@ else
   engykn=evalsum-engyvcl-engyvxc-sm
   deallocate(rfmt)
 end if
+! add vector potential constant term (1/2c²)A²Q if required
+if (tafield) then
+  sm=sum(afieldc(:)**2)
+  engykn=engykn+(0.5d0/solsc**2)*sm*chgval
+end if
 !-------------------------------!
 !     entropic contribution     !
 !-------------------------------!
 entrpy=0.d0
 engyts=0.d0
 ! non-zero only for the Fermi-Dirac smearing function
-if (stype.eq.3) then
+if (stype == 3) then
   sm=0.d0
   do ik=1,nkpt
     w=wkpt(ik)
     do ist=1,nstsv
       f=occsv(ist,ik)/occmax
-      if ((f.gt.0.d0).and.(f.lt.1.d0)) then
+      if ((f > 0.d0).and.(f < 1.d0)) then
         sm=sm+w*(f*log(f)+(1.d0-f)*log(1.d0-f))
       end if
     end do
@@ -261,7 +261,7 @@ end if
 !----------------------!
 engytot=engykn+0.5d0*engyvcl+engymad+engyx+engyc+engyts
 ! add the DFT+U correction if required
-if (dftu.ne.0) engytot=engytot+engydu
+if (dftu /= 0) engytot=engytot+engydu
 ! write total energy to test file
 call writetest(0,'total energy',tol=1.d-5,rv=engytot)
 end subroutine
