@@ -19,7 +19,7 @@ use modomp
 !   classical electrostatic potential from the other nuclei and the electronic
 !   density. This is a result of the Hellmann-Feynman theorem. However because
 !   the basis set is dependent on the nuclear coordinates and is not complete,
-!   the Hellman-Feynman force is inacurate and corrections to it are required.
+!   the Hellman-Feynman force is inaccurate and corrections to it are required.
 !   The first is the core correction which arises because the core wavefunctions
 !   were determined by neglecting the non-spherical parts of the Kohn-Sham
 !   potential $v_s$. Explicitly this is given by
@@ -83,13 +83,13 @@ integer ik,idm,is,ias
 integer nr,nri,i,j,nthd
 real(8) fav(3),ca,t1,t2
 real(8) ts0,ts1
+! automatic arrays
+real(8) grfmt(npmtmax,3)
 ! allocatable arrays
-real(8), allocatable :: rfmt(:,:),grfmt(:,:)
-complex(8), allocatable :: zfmt(:),gzfmt(:,:)
+real(8), allocatable :: rfmt(:,:)
 ! external functions
 real(8), external :: rfmtinp,rfmtint
 call timesec(ts0)
-allocate(zfmt(npmtmax),gzfmt(npmtmax,3))
 ! coupling constant of the external A-field (-1/c)
 ca=-1.d0/solsc
 !---------------------------------!
@@ -99,25 +99,22 @@ do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-  call rtozfmt(nr,nri,vclmt(:,ias),zfmt)
-  call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zfmt,npmtmax,gzfmt)
+  call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),vclmt(:,ias),npmtmax,grfmt)
 ! force from Coulomb potential
-  forcehf(:,ias)=-spzn(is)*dble(gzfmt(1,:))*y00
+  forcehf(:,ias)=-spzn(is)*grfmt(1,:)*y00
 ! force on nuclei from time-dependent E-field
   if (tafieldt) then
     do i=1,3
-      t1=(chgcr(is)+spzn(is))*efieldt(i)
+      t1=(chgsmt(ias,i)+spzn(is))*efieldt(i)
       forcehf(i,ias)=forcehf(i,ias)+t1
     end do
   end if
 end do
-deallocate(zfmt,gzfmt)
 ! symmetrise Hellmann-Feynman forces
 call symveca(forcehf)
 !----------------------------------!
 !     IBS correction to forces     !
 !----------------------------------!
-allocate(grfmt(npmtmax,3))
 ! set the IBS forces to zero
 forceibs(:,:)=0.d0
 ! compute k-point dependent contribution to the IBS forces
@@ -126,13 +123,13 @@ call holdthd(nkpt/np_mpi,nthd)
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkpt
 ! distribute among MPI processes
-  if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+  if (mod(ik-1,np_mpi) /= lp_mpi) cycle
   call forcek(ik)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
 ! add IBS forces from each process and redistribute
-if (np_mpi.gt.1) then
+if (np_mpi > 1) then
   call mpi_allreduce(mpi_in_place,forceibs,3*natmtot,mpi_double_precision, &
    mpi_sum,mpicom,ierror)
 end if
@@ -180,7 +177,7 @@ if (spinpol) then
 end if
 ! time-dependent vector potential times integral of the gradient of the current
 ! density over the muffin-tin
-if (tafieldt) then
+if (tafieldt.and.tjr) then
   do j=1,3
     t1=ca*afieldt(j,itimes)
     do ias=1,natmtot
@@ -200,7 +197,7 @@ end if
 call symveca(forceibs)
 ! total force on each atom
 do ias=1,natmtot
-  forcetot(:,ias)=forcehf(:,ias)+forceibs(:,ias)
+  forcetot(1:3,ias)=forcehf(1:3,ias)+forceibs(1:3,ias)
 end do
 ! symmetrise total forces
 call symveca(forcetot)
@@ -218,15 +215,21 @@ end if
 ! zero force on atoms with negative mass
 do ias=1,natmtot
   is=idxis(ias)
-  if (spmass(is).le.0.d0) forcetot(:,ias)=0.d0
+  if (spmass(is) <= 0.d0) forcetot(1:3,ias)=0.d0
 end do
 ! compute maximum force magnitude over all atoms
 forcemax=0.d0
 do ias=1,natmtot
   t1=sqrt(forcetot(1,ias)**2+forcetot(2,ias)**2+forcetot(3,ias)**2)
-  if (t1.gt.forcemax) forcemax=t1
+  if (t1 > forcemax) forcemax=t1
 end do
-deallocate(grfmt)
+! restrict maximum force magnitude if required
+if (maxforce >= 0.d0) then
+  if (forcemax > maxforce) then
+    t1=maxforce/forcemax
+    forcetot(1:3,1:natmtot)=t1*forcetot(1:3,1:natmtot)
+  end if
+end if
 call timesec(ts1)
 timefor=timefor+ts1-ts0
 ! write total forces to test file
