@@ -6,14 +6,13 @@
 !BOP
 ! !ROUTINE: genspchi0
 ! !INTERFACE:
-subroutine genspchi0(ik,lock,ssr,vqpl,jlgqr,ylmgq,sfacgq,chi0)
+subroutine genspchi0(ik,lock,vqpl,jlgqr,ylmgq,sfacgq,chi0)
 ! !USES:
 use modmain
 use modomp
 ! !INPUT/OUTPUT PARAMETERS:
 !   ik     : k-point from non-reduced set (in,integer)
 !   lock   : OpenMP locks for frequency index of chi0 (in,integer(nwrf))
-!   ssr    : scissor correction (in,real)
 !   vqpl   : input q-point in lattice coordinates (in,real(3))
 !   jlgqr  : spherical Bessel functions evaluated on the coarse radial mesh for
 !            all species and G+q-vectors (in,real(njcmax,nspecies,ngrf))
@@ -62,11 +61,11 @@ implicit none
 ! local variables
 integer, intent(in) :: ik
 integer(8), intent(in) :: lock(nwrf)
-real(8), intent(in) :: ssr,vqpl(3),jlgqr(njcmax,nspecies,ngrf)
+real(8), intent(in) :: vqpl(3),jlgqr(njcmax,nspecies,ngrf)
 complex(8), intent(in) :: ylmgq(lmmaxo,ngrf),sfacgq(ngrf,natmtot)
 complex(8), intent(inout) :: chi0(ngrf,4,ngrf,4,nwrf)
 ! local variables
-logical tz(4),tssr
+logical tz(4)
 integer isym,jk,jkq,iw
 integer nst,nstq,ist,jst,kst,lst
 integer ig,jg,a,b,i,j,nthd
@@ -77,10 +76,10 @@ integer idx(nstsv),idxq(nstsv)
 integer ngp(nspnfv),ngpq(nspnfv)
 ! allocatable arrays
 integer, allocatable :: igpig(:,:),igpqig(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
-complex(8), allocatable :: wfmtq(:,:,:,:),wfirq(:,:,:)
-complex(8), allocatable :: zrhomt(:,:),zrhoir(:),zrhoig(:,:)
-complex(8), allocatable :: zw(:),c(:,:,:,:)
+complex(4), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
+complex(4), allocatable :: wfmtq(:,:,:,:),wfirq(:,:,:)
+complex(4), allocatable :: crhomt(:,:),crhoir(:)
+complex(8), allocatable :: zrhoig(:,:),zw(:),c(:,:,:,:)
 if (.not.spinpol) then
   write(*,*)
   write(*,'("Error(genspchi0): spin-unpolarised calculation")')
@@ -95,42 +94,34 @@ call findkpt(vkql,isym,jkq)
 ! count and index states at k and k+q in energy window
 nst=0
 do ist=1,nstsv
-  if (abs(evalsv(ist,jk)-efermi).lt.emaxrf) then
-    nst=nst+1
-    idx(nst)=ist
-  end if
+  if (abs(evalsv(ist,jk)-efermi) > emaxrf) cycle
+  nst=nst+1
+  idx(nst)=ist
 end do
 nstq=0
-do jst=1,nstsv
-  if (abs(evalsv(jst,jkq)-efermi).lt.emaxrf) then
-    nstq=nstq+1
-    idxq(nstq)=jst
-  end if
+do ist=1,nstsv
+  if (abs(evalsv(ist,jkq)-efermi) > emaxrf) cycle
+  nstq=nstq+1
+  idxq(nstq)=ist
 end do
-! set flag for scissor operator
-if (abs(ssr).gt.1.d-8) then
-  tssr=.true.
-else
-  tssr=.false.
-end if
 ! generate the wavefunctions for all states at k and k+q in energy window
 allocate(igpig(ngkmax,nspnfv))
 allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtc,nspinor,nst))
-call genwfsvp(.false.,.false.,nst,idx,ngdgc,igfc,vkl(:,ik),ngp,igpig,wfmt,ngtc,&
- wfir)
+call genwfsvp_sp(.false.,.false.,nst,idx,ngdgc,igfc,vkl(:,ik),ngp,igpig,wfmt, &
+ ngtc,wfir)
 deallocate(igpig)
 allocate(igpqig(ngkmax,nspnfv))
 allocate(wfmtq(npcmtmax,natmtot,nspinor,nstq),wfirq(ngtc,nspinor,nstq))
-call genwfsvp(.false.,.false.,nstq,idxq,ngdgc,igfc,vkql,ngpq,igpqig,wfmtq,ngtc,&
- wfirq)
+call genwfsvp_sp(.false.,.false.,nstq,idxq,ngdgc,igfc,vkql,ngpq,igpqig,wfmtq, &
+ ngtc,wfirq)
 deallocate(igpqig)
 call holdthd(nst,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zrhomt,zrhoir,zrhoig,zw,c) &
+!$OMP PRIVATE(crhomt,crhoir,zrhoig,zw,c) &
 !$OMP PRIVATE(jst,kst,lst,ei,ej,eij,t1) &
 !$OMP PRIVATE(iw,i,j,a,b,tz,ig,jg,z1) &
 !$OMP NUM_THREADS(nthd)
-allocate(zrhomt(npcmtmax,natmtot),zrhoir(ngtc))
+allocate(crhomt(npcmtmax,natmtot),crhoir(ngtc))
 allocate(zrhoig(ngrf,4),zw(nwrf),c(ngrf,4,ngrf,4))
 !$OMP DO
 do ist=1,nst
@@ -139,17 +130,9 @@ do ist=1,nst
   do jst=1,nstq
     lst=idxq(jst)
     t1=wkptnr*omega*(occsv(kst,jk)-occsv(lst,jkq))
-    if (abs(t1).lt.1.d-8) cycle
+    if (abs(t1) < 1.d-8) cycle
     ej=evalsv(lst,jkq)
     eij=ei-ej
-! scissor operator
-    if (tssr) then
-      if ((ei.gt.efermi).and.(ej.le.efermi)) then
-        eij=eij+ssr
-      else if ((ei.le.efermi).and.(ej.gt.efermi)) then
-        eij=eij-ssr
-      end if
-    end if
 ! frequency-dependent part in response function formula for all frequencies
     do iw=1,nwrf
       zw(iw)=t1/(eij+wrf(iw))
@@ -162,17 +145,17 @@ do ist=1,nst
 ! find which contributions are zero for collinear case
         tz(i)=.false.
         if (.not.ncmag) then
-          if (((a.eq.1).and.(kst.gt.nstfv)).or. &
-              ((a.eq.2).and.(kst.le.nstfv)).or. &
-              ((b.eq.1).and.(lst.gt.nstfv)).or. &
-              ((b.eq.2).and.(lst.le.nstfv))) then
+          if (((a == 1).and.(kst > nstfv)).or. &
+              ((a == 2).and.(kst <= nstfv)).or. &
+              ((b == 1).and.(lst > nstfv)).or. &
+              ((b == 2).and.(lst <= nstfv))) then
             tz(i)=.true.
             cycle
           end if
         end if
-        call genzrho(.true.,.false.,ngtc,wfmt(:,:,a,ist),wfir(:,a,ist), &
-         wfmtq(:,:,b,jst),wfirq(:,b,jst),zrhomt,zrhoir)
-        call zftzf(ngrf,jlgqr,ylmgq,ngrf,sfacgq,zrhomt,zrhoir,zrhoig(:,i))
+        call gencrho(.true.,.false.,ngtc,wfmt(:,:,a,ist),wfir(:,a,ist), &
+         wfmtq(:,:,b,jst),wfirq(:,b,jst),crhomt,crhoir)
+        call zftcf(ngrf,jlgqr,ylmgq,ngrf,sfacgq,crhomt,crhoir,zrhoig(:,i))
       end do
     end do
 ! Hermitian part of matrix
@@ -207,7 +190,7 @@ do ist=1,nst
 ! end loop over ist
 end do
 !$OMP END DO
-deallocate(zrhomt,zrhoir,zrhoig,zw,c)
+deallocate(crhomt,crhoir,zrhoig,zw,c)
 !$OMP END PARALLEL
 call freethd(nthd)
 deallocate(wfmt,wfmtq,wfir,wfirq)
