@@ -35,7 +35,7 @@ close(222)
 10 continue
 !$OMP END CRITICAL(u222)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getdevecfv): differing vectors for k-point ",I8)') ik
   write(*,'(" current : ",3G18.10)') vkl(:,ik)
@@ -43,7 +43,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nmatmax.ne.nmatmax_) then
+if (nmatmax /= nmatmax_) then
   write(*,*)
   write(*,'("Error(getdevecfv): differing nmatmax for k-point ",I8)') ik
   write(*,'(" current : ",I8)') nmatmax
@@ -51,7 +51,7 @@ if (nmatmax.ne.nmatmax_) then
   write(*,*)
   stop
 end if
-if (nstfv.ne.nstfv_) then
+if (nstfv /= nstfv_) then
   write(*,*)
   write(*,'("Error(getdevecfv): differing nstfv for k-point ",I8)') ik
   write(*,'(" current : ",I8)') nstfv
@@ -59,7 +59,7 @@ if (nstfv.ne.nstfv_) then
   write(*,*)
   stop
 end if
-if (nspnfv.ne.nspnfv_) then
+if (nspnfv /= nspnfv_) then
   write(*,*)
   write(*,'("Error(getdevecfv): differing nspnfv for k-point ",I8)') ik
   write(*,'(" current : ",I8)') nspnfv
