@@ -34,7 +34,7 @@ close(226)
 10 continue
 !$OMP END CRITICAL(u226)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getdevecsv): differing vectors for k-point ",I8)') ik
   write(*,'(" current : ",3G18.10)') vkl(:,ik)
@@ -42,7 +42,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(getdevecsv): differing nstsv for k-point ",I8)') ik
   write(*,'(" current : ",I8)') nstsv
