@@ -18,7 +18,7 @@ integer isym,ik
 integer recl,nstfv_,nspnfv_
 real(8) vkl_(3),t1
 character(256) fname
-if (ikp.gt.0) then
+if (ikp > 0) then
   ik=ikp
 else
 ! find the k-point number
@@ -41,7 +41,7 @@ close(200)
 10 continue
 !$OMP END CRITICAL(u200)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getevalfv): differing vectors for k-point ",I8)') ik
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
@@ -49,7 +49,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstfv.ne.nstfv_) then
+if (nstfv /= nstfv_) then
   write(*,*)
   write(*,'("Error(getevalfv): differing nstfv for k-point ",I8)') ik
   write(*,'(" current    : ",I8)') nstfv
@@ -57,7 +57,7 @@ if (nstfv.ne.nstfv_) then
   write(*,*)
   stop
 end if
-if (nspnfv.ne.nspnfv_) then
+if (nspnfv /= nspnfv_) then
   write(*,*)
   write(*,'("Error(getevalfv): differing nspnfv for k-point ",I8)') ik
   write(*,'(" current    : ",I8)') nspnfv
