@@ -21,7 +21,7 @@ read(280,rec=ik) vkl_,nstsv_,nwfm_,se
 close(280)
 !$OMP END CRITICAL(u280)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getgwsefm): differing vectors for k-point ",I8)') ik
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
@@ -29,7 +29,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(getgwsefm): differing nstsv for k-point ",I8)') ik
   write(*,'(" current    : ",I8)') nstsv
@@ -37,7 +37,7 @@ if (nstsv.ne.nstsv_) then
   write(*,*)
   stop
 end if
-if (nwfm.ne.nwfm_) then
+if (nwfm /= nwfm_) then
   write(*,*)
   write(*,'("Error(getgwsefm): differing nwfm for k-point ",I8)') ik
   write(*,'(" current    : ",I8)') nwfm
