@@ -33,7 +33,7 @@ close(300)
 ! central k-point
 ik=(ik0-1)*nkpa+1
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(gethdbulr): differing vectors for k-point ",I8)') ik0
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
@@ -41,7 +41,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(gethdbulr): differing nstsv for k-point ",I8)') ik0
   write(*,'(" current    : ",I8)') nstsv
@@ -49,7 +49,7 @@ if (nstsv.ne.nstsv_) then
   write(*,*)
   stop
 end if
-if (nkpa.ne.nkpa_) then
+if (nkpa /= nkpa_) then
   write(*,*)
   write(*,'("Error(gethdbulr): differing nkpa for k-point ",I8)') ik0
   write(*,'(" current    : ",I8)') nkpa
