@@ -14,7 +14,8 @@ complex(8), intent(out) :: pmat(nstsv,nstsv,3)
 logical tgs
 integer isym,ik,ist,jst
 integer recl,nstsv_
-real(8) vkl_(3),sc(3,3),t1
+real(8) vkl_(3),sc(3,3)
+real(8) ei,ej,eij,t1
 complex(8) v1(3),v2(3)
 ! find the equivalent k-point number and symmetry which rotates vkl to vpl
 call findkpt(vpl,isym,ik)
@@ -32,7 +33,7 @@ close(230)
 10 continue
 !$OMP END CRITICAL(u230)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getpmat): differing vectors for k-point ",I8)') ik
   write(*,'(" current  : ",3G18.10)') vkl(:,ik)
@@ -40,7 +41,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(getpmat): differing nstsv for k-point ",I8)') ik
   write(*,'(" current  : ",I8)') nstsv
@@ -48,9 +49,26 @@ if (nstsv.ne.nstsv_) then
   write(*,*)
   stop
 end if
+! apply scissor correction if required
+if (tscissor) then
+  do jst=1,nstsv
+    ej=evalsv(jst,ik)
+    do ist=1,nstsv
+      ei=evalsv(ist,ik)
+      eij=ei-ej
+! note that the eigenvalues have *already* been scissor corrected
+      if ((ei > efermi).and.(ej <= efermi)) then
+        t1=eij/(eij-scissor)
+      else if ((ei <= efermi).and.(ej > efermi)) then
+        t1=eij/(eij+scissor)
+      end if
+      pmat(ist,jst,1:3)=pmat(ist,jst,1:3)*t1
+    end do
+  end do
+end if
 ! if p = k then return
 t1=abs(vpl(1)-vkl(1,ik))+abs(vpl(2)-vkl(2,ik))+abs(vpl(3)-vkl(3,ik))
-if (t1.lt.epslat) return
+if (t1 < epslat) return
 ! rotate the matrix elements from the reduced to non-reduced k-point
 sc(:,:)=symlatc(:,:,lsplsymc(isym))
 do jst=1,nstsv
