@@ -39,12 +39,12 @@ real(8), allocatable :: work(:)
 call init0
 call init1
 ! initialise q-vector-dependent variables if required
-if (xctype(1).lt.0) call init2
+if (xctype(1) < 0) call init2
 wrtdsk0=wrtdsk
 ! apply strain to the G, k, G+k and q-vectors if required
 call straingkq
-if (task.eq.0) trdstate=.false.
-if (task.eq.1) trdstate=.true.
+if (task == 0) trdstate=.false.
+if (task == 1) trdstate=.true.
 ! only the MPI master process should write files
 if (mp_mpi) then
 ! write the real and reciprocal lattice vectors to file
@@ -81,7 +81,7 @@ if (mp_mpi) then
 ! open MOMENTM.OUT
   if (spinpol) open(68,file='MOMENTM'//trim(filext),form='FORMATTED')
 ! open RESIDUAL.OUT
-  if (xctype(1).lt.0) open(69,file='RESIDUAL'//trim(filext),form='FORMATTED')
+  if (xctype(1) < 0) open(69,file='RESIDUAL'//trim(filext),form='FORMATTED')
 end if
 iscl=0
 if (trdstate) then
@@ -131,12 +131,12 @@ do iscl=1,maxscl
     write(60,'("| Loop number : ",I4," |")') iscl
     write(60,'("+--------------------+")')
   end if
-  if (iscl.ge.maxscl) then
+  if (iscl >= maxscl) then
     if (mp_mpi) then
       write(60,*)
       write(60,'("Reached self-consistent loops maximum")')
     end if
-    if (maxscl.gt.1) then
+    if (maxscl > 1) then
       write(*,*)
       write(*,'("Warning(gndstate): failed to reach self-consistency after ", &
        &I4," loops")') iscl
@@ -179,15 +179,15 @@ do iscl=1,maxscl
 ! generate the density and magnetisation
   call rhomag
 ! DFT+U or fixed tensor moment calculation
-  if ((dftu.ne.0).or.(ftmtype.ne.0)) then
+  if ((dftu /= 0).or.(ftmtype /= 0)) then
 ! generate the muffin-tin density matrix used for computing the potential matrix
     call gendmatmt
 ! write the FTM tensor moments to file
-    if (ftmtype.ne.0) call writeftm
+    if (ftmtype /= 0) call writeftm
 ! generate the DFT+U or FTM muffin-tin potential matrices
     call genvmatmt
   end if
-  if (dftu.ne.0) then
+  if (dftu /= 0) then
     if (mp_mpi) then
 ! write the DFT+U matrices to file
       call writedftu
@@ -197,12 +197,6 @@ do iscl=1,maxscl
   end if
 ! compute the Kohn-Sham potentials and magnetic fields
   call potks(.true.)
-  if (mp_mpi) then
-    if ((xcgrad.eq.3).and.(c_tb09.ne.0.d0)) then
-      write(60,*)
-      write(60,'("Tran-Blaha ''09 constant c : ",G18.10)') c_tb09
-    end if
-  end if
 ! mix the old effective potential and field with the new
   call mixerifc(mixtype,nmix,vsbs,dv,nwork,work)
 ! calculate and add the fixed spin moment effective field (after mixing)
@@ -211,7 +205,7 @@ do iscl=1,maxscl
 ! Fourier transform Kohn-Sham potential to G-space
   call genvsig
 ! reduce the external magnetic fields if required
-  if (reducebf.lt.1.d0) then
+  if (reducebf < 1.d0) then
     bfieldc(:)=bfieldc(:)*reducebf
     bfcmt(:,:,:)=bfcmt(:,:,:)*reducebf
   end if
@@ -249,12 +243,12 @@ do iscl=1,maxscl
     write(64,'(G22.12)') bandgap(1)
     flush(64)
 ! output effective fields for fixed spin moment calculations
-    if (fsmtype.ne.0) call writefsm(60)
+    if (fsmtype /= 0) call writefsm(60)
 ! check for existence of the WRITE file
     call checkwrite(twrite)
 ! check self-consistent loop number modulo nwrite
-    if (nwrite.ge.1) then
-      if (mod(iscl,nwrite).eq.0) twrite=.true.
+    if (nwrite >= 1) then
+      if (mod(iscl,nwrite) == 0) twrite=.true.
     end if
 ! write STATE.OUT file if required
     if (twrite) then
@@ -263,8 +257,9 @@ do iscl=1,maxscl
       write(60,'("Wrote STATE.OUT")')
     end if
 ! write OEP residual
-    if (xctype(1).lt.0) then
+    if (xctype(1) < 0) then
       write(60,*)
+      write(60,'("OEP iterative solver step size : ",G18.10)') tauoep
       write(60,'("Magnitude of OEP residual : ",G18.10)') resoep
       write(69,'(G18.10)') resoep
       flush(69)
@@ -273,7 +268,7 @@ do iscl=1,maxscl
 ! exit self-consistent loop if required
   if (tlast) goto 10
 ! check for convergence
-  if (iscl.ge.2) then
+  if (iscl >= 2) then
     de=abs(engytot-etp)
     if (mp_mpi) then
       write(60,*)
@@ -285,7 +280,7 @@ do iscl=1,maxscl
        &G18.10,")")') de,epsengy
       write(66,'(G18.10)') de
       flush(66)
-      if ((dv.lt.epspot).and.(de.lt.epsengy)) then
+      if ((dv < epspot).and.(de < epsengy)) then
         write(60,*)
         write(60,'("Convergence targets achieved")')
         tlast=.true.
@@ -293,7 +288,7 @@ do iscl=1,maxscl
     end if
   end if
 ! average the current and previous total energies and store
-  if (iscl.gt.1) then
+  if (iscl > 1) then
     etp=0.75d0*engytot+0.25d0*etp
   else
     etp=engytot
@@ -320,7 +315,7 @@ if (mp_mpi) then
   write(60,'("| Self-consistent loop stopped |")')
   write(60,'("+------------------------------+")')
 ! write density and potentials to file only if maxscl > 1
-  if (maxscl.gt.1) then
+  if (maxscl > 1) then
     call writestate
     write(60,*)
     write(60,'("Wrote STATE.OUT")')
@@ -382,7 +377,7 @@ if (mp_mpi) then
 ! close the DTOTENERGY.OUT file
   close(66)
 ! close the RESIDUAL.OUT file
-  if (xctype(1).lt.0) close(69)
+  if (xctype(1) < 0) close(69)
 ! write to VARIABLES.OUT if required
   if (wrtvars) then
     call writevars('engytot',rv=engytot)
