@@ -27,15 +27,15 @@ real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:)
 real(8), allocatable :: jlgqr(:,:,:),jlgqrmt(:,:,:)
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:)
-complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
-complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
-complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:,:)
-complex(8), allocatable :: zvclmt(:,:),zvclir(:)
-complex(8), allocatable :: zrho(:,:,:),epsi(:,:,:)
+complex(4), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
+complex(4), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
+complex(4), allocatable :: crhomt(:,:,:),crhoir(:,:)
+complex(4), allocatable :: cvclmt(:,:),cvclir(:)
+complex(8), allocatable :: zrgq(:,:,:),epsi(:,:,:)
 complex(8), allocatable :: v(:,:),stau(:,:,:)
 complex(8), allocatable :: gs(:,:),wc(:,:),zv(:)
 ! external functions
-complex(8), external :: zfinp
+complex(8), external :: zcfinp
 ! allocate local arrays
 allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
 allocate(jlgqr(njcmax,nspecies,ngrf),jlgqrmt(0:lnpsd,ngvc,nspecies))
@@ -44,8 +44,8 @@ allocate(ylmgq(lmmaxo,ngvc),sfacgq(ngvc,natmtot))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
 allocate(wfmt1(npcmtmax,natmtot,nspinor,nstsv),wfir1(ngtc,nspinor,nstsv))
 allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtc,nspinor,nstsv))
-allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtc,nstsv))
-allocate(zrho(nstsv,ngrf,nstsv),epsi(ngrf,ngrf,nwrf))
+allocate(crhomt(npcmtmax,natmtot,nstsv),crhoir(ngtc,nstsv))
+allocate(zrgq(nstsv,ngrf,nstsv),epsi(ngrf,ngrf,nwrf))
 allocate(v(nstsv,nstsv),stau(nstsv,nstsv,nwgw),gs(nwgw,nstsv))
 ! initialise the OpenMP locks
 allocate(lock(nwgw))
@@ -58,7 +58,7 @@ call getevecsv(filext,ikp,vkl(:,ikp),evecsv)
 ! find the matching coefficients
 call match(ngk(1,ikp),vgkc(:,:,1,ikp),gkc(:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
 ! calculate the wavefunctions for all states of the input k-point
-call genwfsv(.false.,.true.,nstsv,0,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv_sp(.false.,.true.,nstsv,[0],ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 ! local -V_xc and -B_xc matrix elements
 if (spinpol) then
@@ -67,7 +67,7 @@ else
   call genvmatk(vmt,vir,ngk(1,ikp),igkig(:,1,ikp),wfmt1,ngtc,wfir1,v)
 end if
 ! Fourier transform wavefunctions to real-space
-call zftwfir(ngk(1,ikp),igkig(:,1,ikp),wfir1)
+call cftwfir(ngk(1,ikp),igkig(:,1,ikp),wfir1)
 ! add the core Fock matrix elements
 call vclcore(wfmt1,v)
 ! zero the self-energy matrix elements in tau-space
@@ -81,7 +81,7 @@ do ik=1,nkptnr
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  if (any(mod(iv(:),ngridk(:)).ne.0)) cycle
+  if (any(mod(iv(:),ngridk(:)) /= 0)) cycle
   iv(:)=iv(:)/ngridk(:)
   iq=ivqiq(iv(1),iv(2),iv(3))
   vl(:)=vkl(:,ikp)-vkl(:,ik)
@@ -107,51 +107,48 @@ do ik=1,nkptnr
   call getevecfv(filext,0,vkl(:,ik),vgkl(:,:,1,ik),evecfv)
   call getevecsv(filext,0,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states
-  call genwfsv(.false.,.false.,nstsv,0,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv_sp(.false.,.false.,nstsv,[0],ngdgc,igfc,ngk(1,ik),igkig(:,1,ik),&
    apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
+  call holdthd(nstsv,nthd)
 ! determine the complex densities and Fourier transform to G+q-space
   do ist3=1,nstsv
-    call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(zfgq) &
 !$OMP NUM_THREADS(nthd)
     do ist1=1,nstsv
-      call genzrho(.true.,.true.,ngtc,wfmt2(:,:,:,ist3),wfir2(:,:,ist3), &
-       wfmt1(:,:,:,ist1),wfir1(:,:,ist1),zrhomt(:,:,ist1),zrhoir(:,ist1))
-      call zftzf(ngrf,jlgqr,ylmgq,ngvc,sfacgq,zrhomt(:,:,ist1),zrhoir(:,ist1), &
+      call gencrho(.true.,.true.,ngtc,wfmt2(:,:,:,ist3),wfir2(:,:,ist3), &
+       wfmt1(:,:,:,ist1),wfir1(:,:,ist1),crhomt(:,:,ist1),crhoir(:,ist1))
+      call zftcf(ngrf,jlgqr,ylmgq,ngvc,sfacgq,crhomt(:,:,ist1),crhoir(:,ist1), &
        zfgq)
-      zrho(ist1,:,ist3)=conjg(zfgq(:))
+      zrgq(ist1,:,ist3)=conjg(zfgq(:))
     end do
 !$OMP END PARALLEL DO
-    call freethd(nthd)
 !--------------------------------------!
 !     valence Fock matrix elements     !
 !--------------------------------------!
     t1=wqptnr*occsv(ist3,jk)/occmax
-    if (abs(t1).lt.epsocc) cycle
-    call holdthd(nstsv,nthd)
+    if (abs(t1) < epsocc) cycle
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zvclmt,zvclir) &
+!$OMP PRIVATE(cvclmt,cvclir) &
 !$OMP PRIVATE(ist1,z1) &
 !$OMP NUM_THREADS(nthd)
-    allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtc))
+    allocate(cvclmt(npcmtmax,natmtot),cvclir(ngtc))
 !$OMP DO
     do ist2=1,nstsv
 ! calculate the Coulomb potential
-      call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
-       zrhomt(:,:,ist2),zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
-       gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt,zvclir)
-      zvclir(:)=zvclir(:)*cfrc(:)
+      call gencvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
+       crhomt(:,:,ist2),cvclmt)
+      call cpotcoul(nrcmt,nrcmti,npcmt,nrcmtmax,rlcmt,ngdgc,igfc,ngvc,gqc, &
+       gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,crhoir(:,ist2),npcmtmax,cvclmt,cvclir)
+      cvclir(:)=cvclir(:)*cfrc(:)
       do ist1=1,ist2
-        z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
+        z1=zcfinp(crhomt(:,:,ist1),crhoir(:,ist1),cvclmt,cvclir)
         v(ist1,ist2)=v(ist1,ist2)-t1*z1
       end do
     end do
 !$OMP END DO
-    deallocate(zvclmt,zvclir)
+    deallocate(cvclmt,cvclir)
 !$OMP END PARALLEL
-    call freethd(nthd)
   end do
 !-------------------------------------!
 !     correlation matrix elements     !
@@ -159,7 +156,6 @@ do ik=1,nkptnr
 ! symmetrise the Coulomb Green's function
   gclgq(1:ngrf)=sqrt(gclgq(1:ngrf))
 ! generate G_s in tau-space
-  call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(t1,iw) &
 !$OMP NUM_THREADS(nthd)
@@ -185,7 +181,7 @@ do ik=1,nkptnr
   do jg=1,ngrf
 ! if epsi is exactly zero then there is no entry for this particular G'+q-vector
 ! so we cycle to the next
-    if (abs(epsi(jg,jg,1)).eq.0.d0) cycle
+    if (abs(epsi(jg,jg,1)) == 0.d0) cycle
 ! subtract one from inverse epsilon to leave just the correlation part
     epsi(jg,jg,:)=epsi(jg,jg,:)-1.d0
 ! compute the correlation part of the screened interaction W_c
@@ -207,25 +203,25 @@ do ik=1,nkptnr
         if (twdiag) then
 ! use only the diagonal elements of W_c
           z2=z1*wc(it,jg)
-          call zaxpy(nstsv,z2,zrho(:,jg,ist3),1,zv,1)
+          call zaxpy(nstsv,z2,zrgq(:,jg,ist3),1,zv,1)
         else
 ! use the full W_c
           do ig=1,ngrf
             z2=z1*wc(it,ig)
-            call zaxpy(nstsv,z2,zrho(:,ig,ist3),1,zv,1)
+            call zaxpy(nstsv,z2,zrgq(:,ig,ist3),1,zv,1)
           end do
         end if
         call omp_set_lock(lock(it))
         if (tsediag) then
 ! compute only the diagonal elements of the self-energy
           do ist2=1,nstsv
-            z2=conjg(zrho(ist2,jg,ist3))
+            z2=conjg(zrgq(ist2,jg,ist3))
             stau(ist2,ist2,it)=stau(ist2,ist2,it)+z2*zv(ist2)
           end do
         else
 ! compute the full self-energy matrix
           do ist2=1,nstsv
-            z2=conjg(zrho(ist2,jg,ist3))
+            z2=conjg(zrgq(ist2,jg,ist3))
             call zaxpy(nstsv,z2,zv,1,stau(:,ist2,it),1)
           end do
         end if
@@ -288,6 +284,6 @@ call freethd(nthd)
 deallocate(vgqc,gqc,gclgq,jlgqr,jlgqrmt)
 deallocate(ylmgq,sfacgq,apwalm,evecfv,evecsv)
 deallocate(wfmt1,wfir1,wfmt2,wfir2)
-deallocate(zrhomt,zrhoir,zrho,epsi,v,gs)
+deallocate(crhomt,crhoir,zrgq,epsi,v,gs)
 end subroutine
 
