@@ -49,7 +49,7 @@ allocate(sf(nwplot),se(nstsv,nstsv,0:nwfm))
 !$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
-  if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+  if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(gwspecf_1)
   write(*,'("Info(gwspecf): ",I6," of ",I6," k-points")') ik,nkpt
 !$OMP END CRITICAL(gwspecf_1)
@@ -71,7 +71,7 @@ deallocate(sf,se)
 !$OMP END PARALLEL
 call freethd(nthd)
 ! add total spectral function from each process
-if (np_mpi.gt.1) then
+if (np_mpi > 1) then
   call mpi_allreduce(mpi_in_place,sft,nwplot,mpi_double_precision,mpi_sum, &
    mpicom,ierror)
 end if
