@@ -9,7 +9,7 @@ use modmpi
 implicit none
 ! local variables
 integer idm,it
-real(8) tau
+real(8) resp
 ! allocatable arrays
 real(8), allocatable :: rhomt_(:,:),rhoir_(:)
 real(8), allocatable :: magmt_(:,:,:),magir_(:,:)
@@ -17,30 +17,26 @@ real(8), allocatable :: rfmt(:,:),rfir(:)
 ! copy the existing density and magnetisation
 allocate(rhomt_(npmtmax,natmtot),rhoir_(ngtot))
 call rfcopy(rhomt,rhoir,rhomt_,rhoir_)
-allocate(rfmt(npmtmax,natmtot),rfir(ngtot))
 if (spinpol) then
   allocate(magmt_(npmtmax,natmtot,ndmag),magir_(ngtot,ndmag))
   do idm=1,ndmag
     call rfcopy(magmt(:,:,idm),magir(:,idm),magmt_(:,:,idm),magir_(:,idm))
   end do
 end if
-! initialise the exchange-correlation potential and magnetic field
-tau=tauoep(2)
-vxcmt(:,:)=tau*vxcmt(:,:)
-vxcir(:)=tau*vxcir(:)
+allocate(rfmt(npmtmax,natmtot),rfir(ngtot))
+! zero the exchange-correlation potential and magnetic field
+vxcmt(:,:)=0.d0
+vxcir(:)=0.d0
 if (spinpol) then
-  bxcmt(:,:,:)=tau*bxcmt(:,:,:)
-  bxcir(:,:)=tau*bxcir(:,:)
+  bxcmt(:,:,:)=0.d0
+  bxcir(:,:)=0.d0
 end if
-! iterative method step size
-tau=tauoep(1)
 if (mp_mpi) then
-  write(*,*)
   write(*,'("Info(ksinvert): inverting the Kohn-Sham equations")')
 end if
-do it=1,maxitoep
-  if (mp_mpi.and.(mod(it,10).eq.0)) then
-    write(*,'("Info(ksinvert): done ",I4," iterations of ",I4)') it,maxitoep
+do it=1,maxitksi
+  if (mp_mpi.and.(mod(it,10) == 0)) then
+    write(*,'("Info(ksinvert): done ",I4," iterations of ",I4)') it,maxitksi
   end if
   call hmlrad
   call genevfsv
@@ -48,6 +44,17 @@ do it=1,maxitoep
   call rhomag
 ! determine the residual and add it to the exchange-correlation potential
   call residual
+! update the step size
+  if (it >= 2) then
+! check residual against previous value
+    if (resksi < resp) then
+      tauksi=tauksi+tau0ksi
+    else
+      tauksi=tau0ksi
+    end if
+  end if
+! store previous residual
+  resp=resksi
 ! set the constant part of V_xc equal to zero
   call rfint0(0.d0,vxcmt,vxcir)
 ! add the external and Hartree potentials
@@ -72,25 +79,25 @@ do ias=1,natmtot
   is=idxis(ias)
   np=npmt(is)
   rfmt(1:np,ias)=rhomt(1:np,ias)-rhomt_(1:np,ias)
-  call daxpy(np,tau,rfmt(:,ias),1,vxcmt(:,ias),1)
+  vxcmt(1:np,ias)=vxcmt(1:np,ias)+tauksi*rfmt(1:np,ias)
 end do
 rfir(:)=rhoir(:)-rhoir_(:)
-call daxpy(ngtot,tau,rfir,1,vxcir,1)
-resoep=rfinp(rfmt,rfir,rfmt,rfir)
+vxcir(:)=vxcir(:)+tauksi*rfir(:)
+resksi=rfinp(rfmt,rfir,rfmt,rfir)
 if (spinpol) then
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
       np=npmt(is)
       rfmt(1:np,ias)=magmt(1:np,ias,idm)-magmt_(1:np,ias,idm)
-      call daxpy(np,tau,rfmt(:,ias),1,bxcmt(:,ias,idm),1)
+      bxcmt(1:np,ias,idm)=bxcmt(1:np,ias,idm)+tauksi*rfmt(1:np,ias)
     end do
     rfir(:)=magir(:,idm)-magir_(:,idm)
-    call daxpy(ngtot,tau,rfir,1,bxcir(:,idm),1)
-    resoep=resoep+rfinp(rfmt,rfir,rfmt,rfir)
+    bxcir(:,idm)=bxcir(:,idm)+tauksi*rfir(:)
+    resksi=resksi+rfinp(rfmt,rfir,rfmt,rfir)
   end do
 end if
-resoep=sqrt(resoep)/omega
+resksi=sqrt(resksi)/omega
 end subroutine
 
 end subroutine
