@@ -56,14 +56,16 @@ real(8) datposl(3,maxatoms,maxspecies)
 real(8) atposc(3,maxatoms,maxspecies),atposc0(3,maxatoms,maxspecies)
 ! magnitude of random displacements added to the atomic positions
 real(8) rndatposc
-! tdatpos is .true. if small amplitude displacements are to be included when
-! calculating the Coulomb potential
-logical :: tdatpos=.false.
-! trddatpos is .true. if the small amplitude displacements and velocities are to
-! be read from file
-logical :: trddatpos=.false.
-! small amplitude atomic displacements and velocities
-real(8) datposc(3,0:1,maxatoms,maxspecies)
+! tatdisp is .true. if small amplitude atomic displacements are to be included
+! when calculating the Coulomb potential
+logical :: tatdisp=.false.
+! trdatdv is .true. if the atomic displacements and velocities are to be read
+! from file
+logical trdatdv
+! atomic displacements and velocities in Cartesian coordinates
+real(8) atdvc(3,0:1,maxatoms,maxspecies)
+! atomic damping force coefficient
+real(8) atdfc
 
 !----------------------------------!
 !     atomic species variables     !
@@ -149,7 +151,12 @@ real(8) rmtall
 ! minimum allowed distance between muffin-tin surfaces
 real(8) rmtdelta
 ! muffin-tin radii
-real(8) rmt(maxspecies)
+real(8) rmt(maxspecies),rmt0(maxspecies)
+! trmt0 is .true. if the original muffin-tin radii rmt0 are to be retained
+! between tasks
+logical trmt0
+! (R_mt)^l for l up to lmaxo+3
+real(8), allocatable :: rmtl(:,:)
 ! total muffin-tin volume
 real(8) omegamt
 ! radial step length for coarse mesh
@@ -199,6 +206,8 @@ integer npmti(maxspecies),npmt(maxspecies)
 integer npcmti(maxspecies),npcmt(maxspecies)
 ! maximum number of points over all packed muffin-tins
 integer npmtmax,npcmtmax
+! smoothing order used when calculating gradients in the muffin-tin
+integer msmgmt
 
 !--------------------------------!
 !     spin related variables     !
@@ -224,7 +233,7 @@ logical spcpl
 !  3 (-3) : total and muffin-tin moments (direction)
 integer fsmtype,fsmtype0
 ! fixed total spin magnetic moment
-real(8) momfix(3),momfix0(3)
+real(8) momfix(3),momfix0(3),dmomfix(3)
 ! fixed spin moment global effective field in Cartesian coordinates
 real(8) bfsmc(3)
 ! muffin-tin fixed spin moments
@@ -238,7 +247,7 @@ integer nspinor
 ! global external magnetic field in Cartesian coordinates
 real(8) bfieldc(3)
 ! initial field
-real(8) bfieldc0(3),bfieldc00(3)
+real(8) bfieldc0(3),bfieldc00(3),dbfieldc0(3)
 ! external magnetic field in each muffin-tin in Cartesian coordinates
 real(8) bfcmt(3,maxatoms,maxspecies)
 ! initial field as read in from input file
@@ -247,6 +256,8 @@ real(8) bfcmt0(3,maxatoms,maxspecies),bfcmt00(3,maxatoms,maxspecies)
 real(8) rndbfcmt
 ! external magnetic fields are multiplied by reducebf after each s.c. loop
 real(8) reducebf,reducebf0
+! small change in magnetic field used for calculating the magnetoelectric tensor
+real(8) deltabf
 ! spinsprl is .true. if a spin-spiral is to be calculated
 logical spinsprl,spinsprl0
 ! ssdph is .true. if the muffin-tin spin-spiral magnetisation is de-phased
@@ -340,17 +351,17 @@ integer, allocatable :: lspnsyms(:,:)
 real(8) gmaxvr,dgmaxvr
 ! G-vector grid sizes
 integer ngridg(3),ngridg0(3)
-! G-vector grid sizes for coarse grid (G < 2*gkmax)
+! G-vector grid sizes for coarse grid with |G| < 2 gkmax
 integer ngdgc(3)
 ! total number of G-vectors
 integer ngtot,ngtot0
-! total number of G-vectors for coarse grid (G < 2*gkmax)
+! total number of G-vectors for coarse grid
 integer ngtc
 ! integer grid intervals for each direction
 integer intgv(2,3)
-! number of G-vectors with G < gmaxvr
+! number of G-vectors with |G| < gmaxvr
 integer ngvec
-! number of G-vectors for coarse grid (G < 2*gkmax)
+! number of G-vectors for coarse grid with |G| < 2 gkmax
 integer ngvc
 ! G-vector integer coordinates (i1,i2,i3)
 integer, allocatable :: ivg(:,:),ivg0(:,:)
@@ -358,7 +369,7 @@ integer, allocatable :: ivg(:,:),ivg0(:,:)
 integer, allocatable :: ivgig(:,:,:)
 ! map from G-vector index to FFT array
 integer, allocatable :: igfft(:),igfft0(:)
-! map from G-vector index to FFT array for coarse grid (G < 2*gkmax)
+! map from G-vector index to FFT array for coarse grid
 integer, allocatable :: igfc(:)
 ! G-vectors in Cartesian coordinates
 real(8), allocatable :: vgc(:,:)
@@ -378,7 +389,7 @@ real(8), allocatable :: ffacg(:,:)
 complex(8), allocatable :: cfunig(:)
 ! characteristic function in real-space: 0 inside the muffin-tins and 1 outside
 real(8), allocatable :: cfunir(:)
-! characteristic function in real-space for coarse grid (G < 2*gkmax)
+! characteristic function in real-space for coarse grid
 real(8), allocatable :: cfrc(:)
 
 !---------------------------!
@@ -529,13 +540,26 @@ complex(4), allocatable :: cbshto(:,:),cfshto(:,:)
 ! exchange-correlation functional type
 integer xctype(3)
 ! exchange-correlation functional description
-character(512) xcdescr
+character(264) xcdescr
 ! exchange-correlation functional spin requirement
 integer xcspin
 ! exchange-correlation functional density gradient requirement
+!  0 : no gradients
+!  1 : gradients required for GGA with no post-processing: |grad rho|,
+!      grad^2 rho, (grad rho).(grad |grad rho|)
+!  2 : gradients required for GGA with post-processing: |grad rho|^2
+!  3 : as 2 but with the laplacian, grad^2 rho
+!  4 : as 2 but with the kinetic energy density, tau
+!  5 : as 4 but with the laplacian, grad^2 rho
 integer xcgrad
 ! small constant used to stabilise non-collinear GGA
 real(8) dncgga
+! kinetic energy density functional type
+integer ktype(3)
+! kinetic energy density functional description
+character(264) kdescr
+! kinetic energy density density gradient requirement (see xcgrad)
+integer kgrad
 ! muffin-tin and interstitial charge density
 real(8), allocatable :: rhomt(:,:),rhoir(:)
 ! trhonorm is .true. if the density is to be normalised after every iteration
@@ -546,9 +570,6 @@ real(8), allocatable :: magmt(:,:,:),magir(:,:)
 logical tjr,tjr0
 ! muffin-tin and interstitial gauge-invariant current density vector field
 real(8), allocatable :: jrmt(:,:,:),jrir(:,:)
-! amount of smoothing to be applied to the exchange-correlation potentials and
-! magnetic field
-integer msmooth,msmooth0
 ! muffin-tin and interstitial Coulomb potential
 real(8), allocatable :: vclmt(:,:),vclir(:)
 ! Poisson solver pseudocharge density constant
@@ -571,20 +592,23 @@ logical tbdip
 ! combined target array for vsmt, vsir, bsmt and bsir
 real(8), allocatable, target :: vsbs(:)
 ! muffin-tin and interstitial Kohn-Sham effective potential
-real(8), pointer :: vsmt(:,:),vsir(:)
+real(8), pointer, contiguous :: vsmt(:,:),vsir(:)
 ! muffin-tin Kohn-Sham effective magnetic field in spherical coordinates and on
 ! a coarse radial mesh
-real(8), pointer :: bsmt(:,:,:)
+real(8), pointer, contiguous :: bsmt(:,:,:)
 ! interstitial Kohn-Sham effective magnetic field
-real(8), pointer :: bsir(:,:)
+real(8), pointer, contiguous :: bsir(:,:)
 ! G-space interstitial Kohn-Sham effective potential
 complex(8), allocatable :: vsig(:)
+! trimvg is .true. if the components of the effective potential are to be set to
+! zero for |G| > 4 gkmax before the characteristic function is applied
+logical trimvg,trimvg0
 ! nosource is .true. if the field is to be made source-free
 logical nosource
 ! tssxc is .true. if scaled spin exchange-correlation is to be used
 logical tssxc
 ! spin exchange-correlation scaling factor
-real(8) sxcscf
+real(8) sxcscf,dsxcscf
 ! spin-orbit coupling radial function
 real(8), allocatable :: socfr(:,:)
 ! kinetic energy density
@@ -593,10 +617,6 @@ real(8), allocatable :: taumt(:,:,:),tauir(:,:)
 real(8), allocatable :: taucr(:,:,:)
 ! meta-GGA exchange-correlation potential
 real(8), allocatable :: wxcmt(:,:),wxcir(:)
-! Tran-Blaha '09 constant c [Phys. Rev. Lett. 102, 226401 (2009)]
-real(8) c_tb09
-! tc_tb09 is .true. if the Tran-Blaha constant has been read in
-logical tc_tb09
 ! if trdstate is .true. the density and potential can be read from STATE.OUT
 logical :: trdstate=.false.
 ! temperature in degrees Kelvin
@@ -632,7 +652,7 @@ real(8), allocatable :: chgcrlk(:)
 ! total valence charge
 real(8) chgval
 ! excess charge
-real(8) chgexs
+real(8) chgexs,dchgexs
 ! total charge
 real(8) chgtot
 ! calculated total charge
@@ -803,7 +823,9 @@ real(8) epsocc
 real(8), allocatable :: occsv(:,:)
 ! Fermi energy for second-variational states
 real(8) efermi
-! scissor correction applied when computing response functions
+! tscissor is .true. if the scissor correction is non-zero
+logical tscissor
+! scissor correction applied to eigenvalues and momentum matric elements
 real(8) scissor
 ! density of states at the Fermi energy
 real(8) fermidos
@@ -893,6 +915,9 @@ real(8), allocatable :: forcetot(:,:)
 real(8), allocatable :: forcetotp(:,:)
 ! maximum force magnitude over all atoms
 real(8) forcemax
+! maximum allowed force magnitude; if this force is reached for any atom then
+! all forces are rescaled so that the maximum force magnitude is this value
+real(8) maxforce
 ! tfav0 is .true. if the average force should be zero in order to prevent
 ! translation of the atomic basis
 logical tfav0,tfav00
@@ -912,8 +937,8 @@ integer nstrain
 integer :: istrain=0
 ! strain tensors
 real(8) strain(3,3,9)
-! infinitesimal displacement parameter multiplied by the strain tensor for
-! computing the stress tensor
+! small displacement parameter multiplied by the strain tensor for computing the
+! stress tensor; also used for calculating the piezoelectric tensor
 real(8) deltast
 ! symmetry reduced stress tensor components
 real(8) stress(9)
@@ -1001,6 +1026,8 @@ real(8) wsfac(2)
 integer nvp1d
 ! total number of points in 1D plot
 integer npp1d
+! starting point for 1D plot
+integer ip01d
 ! vertices in lattice coordinates for 1D plot
 real(8), allocatable :: vvlp1d(:,:)
 ! distance to vertices in 1D plot
@@ -1018,24 +1045,33 @@ real(8) vclp3d(3,0:3)
 ! grid sizes of 3D plot
 integer np3d(3)
 
-!----------------------------------------!
-!     OEP and Hartree-Fock variables     !
-!----------------------------------------!
+!-------------------------------------------------------------!
+!     OEP, Hartree-Fock and Kohn-Sham inversion variables     !
+!-------------------------------------------------------------!
 ! maximum number of core states over all species
 integer ncrmax
 ! maximum number of OEP iterations
 integer maxitoep
-! OEP step size and fraction of previous potential to be used as starting point
-real(8) tauoep(2)
-! magnitude of the OEP residual
-real(8) resoep
+! OEP initial and subsequent step sizes
+real(8) tau0oep,tauoep
 ! exchange potential and magnetic field
 real(8), allocatable :: vxmt(:,:),vxir(:)
 real(8), allocatable :: bxmt(:,:,:),bxir(:,:)
+! OEP residual functions
+real(8), allocatable :: dvxmt(:,:),dvxir(:)
+real(8), allocatable :: dbxmt(:,:,:),dbxir(:,:)
+! magnitude of the OEP residual
+real(8) resoep
 ! hybrid is .true. if a hybrid functional is to be used
 logical hybrid,hybrid0
 ! hybrid functional mixing coefficient
 real(8) hybridc
+! maximum number of KS inversion iterations
+integer maxitksi
+! KS inversion initial and subsequent step sizes
+real(8) tau0ksi,tauksi
+! magnitude of the KS inversion residual
+real(8) resksi
 
 !-------------------------------------------------------------!
 !     response function and perturbation theory variables     !
@@ -1117,22 +1153,22 @@ real(8), parameter :: fourpi=12.566370614359172954d0
 ! spherical harmonic for l=m=0
 real(8), parameter :: y00=0.28209479177387814347d0
 ! complex constants
-complex(8), parameter :: zzero=(0.d0,0.d0)
-complex(8), parameter :: zone=(1.d0,0.d0)
+complex(4), parameter :: czero=(0.e0,0.e0),cone=(1.e0,0.e0)
+complex(8), parameter :: zzero=(0.d0,0.d0),zone=(1.d0,0.d0)
 complex(8), parameter :: zi=(0.d0,1.d0)
 ! array of i^l and (-i)^l values
 complex(8), parameter :: zil(0:3)=[zone,zi,-zone,-zi]
 complex(8), parameter :: zilc(0:3)=[zone,-zi,-zone,zi]
 ! Pauli spin matrices:
-! sigma_x = ( 0  1 )   sigma_y = ( 0 -i )   sigma_z = ( 1  0 )
-!           ( 1  0 )             ( i  0 )             ( 0 -1 )
+! σ_x = ⎛0  1⎞   σ_y = ⎛0 -i⎞   σ_z = ⎛1  0⎞
+!       ⎝1  0⎠         ⎝i  0⎠         ⎝0 -1⎠
 ! Planck constant in SI units (exact, CODATA 2018)
 real(8), parameter :: h_si=6.62607015d-34
 ! reduced Planck constant in SI units
 real(8), parameter :: hbar_si=h_si/twopi
 ! speed of light in SI units (exact, CODATA 2018)
 real(8), parameter :: sol_si=299792458d0
-! speed of light in atomic units (=1/alpha) (CODATA 2018)
+! speed of light in atomic units (1/α) (CODATA 2018)
 real(8), parameter :: sol=137.035999084d0
 ! scaled speed of light
 real(8) solsc
@@ -1171,7 +1207,7 @@ real(8), parameter :: amu=amu_si/em_si
 !     miscellaneous variables     !
 !---------------------------------!
 ! code version
-integer, parameter :: version(3)=[8,4,30]
+integer, parameter :: version(3)=[9,2,5]
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
