@@ -33,7 +33,7 @@ call init2
 call init4
 ! check k-point grid is commensurate with q-point grid
 iv(:)=mod(ngridk(:),ngridq(:))
-if ((iv(1).ne.0).or.(iv(2).ne.0).or.(iv(3).ne.0)) then
+if ((iv(1) /= 0).or.(iv(2) /= 0).or.(iv(3) /= 0)) then
   write(*,*)
   write(*,'("Error(phonon): k-point grid incommensurate with q-point grid")')
   write(*,'(" ngridk : ",3I6)') ngridk
@@ -55,7 +55,7 @@ if (ssdph) then
   stop
 end if
 ! check for zero atoms
-if (natmtot.eq.0) return
+if (natmtot == 0) return
 ! read in the density and potentials
 call readstate
 ! Fourier transform Kohn-Sham potential to G-space
@@ -77,7 +77,7 @@ end do
 nmix=2*size(dvsbs)
 ! determine the size of the mixer work array
 nwork=-1
-call mixerifc(mtype,nmix,dvsbs,ddv,nwork,dvsbs)
+call mixerifc(mtype,nmix,dvsbs,ddv,nwork,work)
 allocate(work(nwork))
 ! allocate dynamical matrix column
 allocate(dyn(3,natmtot))
@@ -85,7 +85,7 @@ allocate(dyn(3,natmtot))
 10 continue
 call dyntask(80,fext)
 ! if nothing more to do then return
-if (iqph.eq.0) return
+if (iqph == 0) return
 if (mp_mpi) then
   write(*,'("Info(phonon): working on ",A)') 'DYN'//trim(fext)
 ! open RMSDDVS.OUT
@@ -94,7 +94,7 @@ end if
 ! zero the dynamical matrix row
 dyn(:,:)=0.d0
 ! check to see if mass is considered infinite
-if (spmass(isph).le.0.d0) goto 20
+if (spmass(isph) <= 0.d0) goto 20
 ! generate the G+k+q-vectors and related quantities
 call gengkqvec(iqph)
 ! generate the G+q-vectors and related quantities
@@ -146,10 +146,10 @@ do iscl=1,maxscl
   allocate(dapwalmq(ngkmax,apwordmax,lmmaxapw,nspnfv))
   allocate(evecfv(nmatmax,nstfv,nspnfv),devecfv(nmatmax,nstfv,nspnfv))
   allocate(evecsv(nstsv,nstsv),devecsv(nstsv,nstsv))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do ik=1,nkptnr
 ! distribute among MPI processes
-    if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+    if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 ! equivalent reduced k-point
     jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! compute the matching coefficients and derivatives
@@ -218,7 +218,7 @@ devalsv(:,ik)=devalfv(:,1,ik)
     call zfmtctof(dmagmt(:,:,idm))
   end do
 ! add densities from each process and redistribute
-  if (np_mpi.gt.1) then
+  if (np_mpi > 1) then
     n=npmtmax*natmtot
     call mpi_allreduce(mpi_in_place,drhomt,n,mpi_double_complex,mpi_sum, &
      mpicom,ierror)
@@ -248,8 +248,8 @@ devalsv(:,ik)=devalfv(:,1,ik)
 ! exit self-consistent loop if required
   if (tlast) goto 20
 ! check for convergence
-  if (iscl.ge.2) then
-    if (ddv.lt.epspot) tlast=.true.
+  if (iscl >= 2) then
+    if (ddv < epspot) tlast=.true.
   end if
 ! broadcast tlast from master process to all other processes
   call mpi_bcast(tlast,1,mpi_logical,0,mpicom,ierror)
@@ -279,8 +279,8 @@ if (mp_mpi) then
     do ip=1,3
       a=dble(dyn(ip,ias))
       b=aimag(dyn(ip,ias))
-      if (abs(a).lt.1.d-12) a=0.d0
-      if (abs(b).lt.1.d-12) b=0.d0
+      if (abs(a) < 1.d-12) a=0.d0
+      if (abs(b) < 1.d-12) b=0.d0
       write(80,'(2G18.10," : is = ",I4,", ia = ",I4,", ip = ",I4)') a,b,is,ia,ip
     end do
   end do
