@@ -47,11 +47,11 @@ occsv(:,:)=occsv(:,:)+t1
 sm=0.d0
 do ik=1,nkpt
   do ist=1,nstsv
-    if (occsv(ist,ik).gt.occmax) then
+    if (occsv(ist,ik) > occmax) then
       sm=sm+wkpt(ik)*(occsv(ist,ik)-occmax)
       occsv(ist,ik)=occmax
     end if
-    if (occsv(ist,ik).lt.0.d0) then
+    if (occsv(ist,ik) < 0.d0) then
       sm=sm+wkpt(ik)*occsv(ist,ik)
       occsv(ist,ik)=0.d0
     end if
@@ -59,7 +59,7 @@ do ik=1,nkpt
 end do
 do ist=1,nstsv
   do ik=1,nkpt
-    if (sm.gt.0.d0) then
+    if (sm > 0.d0) then
       t1=wkpt(ik)*(occmax-occsv(ist,ik))
       t1=min(t1,sm)
       occsv(ist,ik)=occsv(ist,ik)+t1/wkpt(ik)
@@ -86,7 +86,7 @@ do it=1,maxit
   do ik=1,nkpt
     do ist=1,nstsv
       t1=dedn(ist,ik)-kapa
-      if (t1.gt.0.d0) then
+      if (t1 > 0.d0) then
         gamma(ist,ik)=t1*(occmax-occsv(ist,ik))
       else
         gamma(ist,ik)=t1*occsv(ist,ik)
@@ -98,11 +98,11 @@ do it=1,maxit
   sm=sqrt(sm)
   sm=max(sm,1.d0)
   t1=abs(gs)/sm
-  if (t1.lt.eps) goto 10
-  if (it.ge.2) then
+  if (t1 < eps) goto 10
+  if (it >= 2) then
     dgs=gs-gsp
-    if (gs*dgs.gt.0.d0) dkapa=-dkapa
-    if (gs*gsp.lt.0.d0) then
+    if (gs*dgs > 0.d0) dkapa=-dkapa
+    if (gs*gsp < 0.d0) then
       dkapa=0.5d0*dkapa
     else
       dkapa=1.1d0*dkapa
@@ -126,25 +126,25 @@ do ik=1,nkpt
     sm=sm+wkpt(ik)*gamma(ist,ik)**2
   end do
 end do
-if (sm.gt.1.d0) then
+if (sm > 1.d0) then
   t1=1.d0/sqrt(sm)
   gamma(:,:)=t1*gamma(:,:)
 end if
 ! find step size which keeps occupancies in the interval [0,occmax]
 tau=taurdmn
 20 continue
-if (abs(tau).lt.eps) goto 30
+if (abs(tau) < eps) goto 30
 do ik=1,nkpt
   do ist=1,nstsv
     t1=occsv(ist,ik)+tau*gamma(ist,ik)
-    if (gamma(ist,ik).gt.0.d0) then
-      if (t1.gt.occmax+eps) then
+    if (gamma(ist,ik) > 0.d0) then
+      if (t1 > occmax+eps) then
         tau=0.75d0*tau
         goto 20
       end if
     end if
-    if (gamma(ist,ik).lt.0.d0) then
-      if (t1.lt.-eps) then
+    if (gamma(ist,ik) < 0.d0) then
+      if (t1 < -eps) then
         tau=0.75d0*tau
         goto 20
       end if
