@@ -14,7 +14,7 @@ e0min=0.d0
 do is=1,nspecies
   open(50,file=trim(sppath)//trim(spfname(is)),status='OLD',form='FORMATTED', &
    action='READ',iostat=ios)
-  if (ios.ne.0) then
+  if (ios /= 0) then
     write(*,*)
     write(*,'("Error(readspecies): error opening species file ",A)') &
      trim(sppath)//trim(spfname(is))
@@ -26,14 +26,14 @@ do is=1,nspecies
   read(50,*) spzn(is)
   read(50,*) spmass(is)
   read(50,*) rminsp(is),rmt(is),rmaxsp(is),nrmt(is)
-  if (rminsp(is).le.0.d0) then
+  if (rminsp(is) <= 0.d0) then
     write(*,*)
     write(*,'("Error(readspecies): rminsp <= 0 : ",G18.10)') rminsp(is)
     write(*,'(" for species ",I4)') is
     write(*,*)
     stop
   end if
-  if (rmt(is).le.rminsp(is)) then
+  if (rmt(is) <= rminsp(is)) then
     write(*,*)
     write(*,'("Error(readspecies): rmt <= rminsp : ",2G18.10)') rmt(is), &
      rminsp(is)
@@ -41,14 +41,14 @@ do is=1,nspecies
     write(*,*)
     stop
   end if
-  if (rmaxsp(is).lt.rmt(is)) then
+  if (rmaxsp(is) < rmt(is)) then
     write(*,*)
     write(*,'("Error(readspecies): rmaxsp < rmt : ",2G18.10)') rmaxsp(is), &
      rmt(is)
     write(*,*)
     stop
   end if
-  if (nrmt(is).lt.20) then
+  if (nrmt(is) < 20) then
     write(*,*)
     write(*,'("Error(readspecies): nrmt too small : ",I8)') nrmt(is)
     write(*,'(" for species ",I4)') is
@@ -60,7 +60,7 @@ do is=1,nspecies
 ! reduce the minimum radial mesh point by the same factor
   rminsp(is)=rminsp(is)/nrmtscf
   read(50,*) nstsp(is)
-  if ((nstsp(is).le.0).or.(nstsp(is).gt.maxstsp)) then
+  if ((nstsp(is) <= 0).or.(nstsp(is) > maxstsp)) then
     write(*,*)
     write(*,'("Error(readspecies): nstsp out of range : ",I8)') nstsp(is)
     write(*,'(" for species ",I4)') is
@@ -69,7 +69,7 @@ do is=1,nspecies
   end if
   do ist=1,nstsp(is)
     read(50,*) nsp(ist,is),lsp(ist,is),ksp(ist,is),occsp(ist,is),spcore(ist,is)
-    if (nsp(ist,is).lt.1) then
+    if (nsp(ist,is) < 1) then
       write(*,*)
       write(*,'("Error(readspecies): nsp < 1 : ",I8)') nsp(ist,is)
       write(*,'(" for species ",I4)') is
@@ -77,7 +77,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (lsp(ist,is).lt.0) then
+    if (lsp(ist,is) < 0) then
       write(*,*)
       write(*,'("Error(readspecies): lsp < 0 : ",I8)') lsp(ist,is)
       write(*,'(" for species ",I4)') is
@@ -85,7 +85,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (ksp(ist,is).lt.1) then
+    if (ksp(ist,is) < 1) then
       write(*,*)
       write(*,'("Error(readspecies): ksp < 1 : ",I8)') ksp(ist,is)
       write(*,'(" for species ",I4)') is
@@ -93,7 +93,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (occsp(ist,is).lt.0.d0) then
+    if (occsp(ist,is) < 0.d0) then
       write(*,*)
       write(*,'("Error(readspecies): occsp < 0 : ",G18.10)') occsp(ist,is)
       write(*,'(" for species ",I4)') is
@@ -103,14 +103,14 @@ do is=1,nspecies
     end if
   end do
   read(50,*) apword(0,is)
-  if (apword(0,is).le.0) then
+  if (apword(0,is) <= 0) then
     write(*,*)
     write(*,'("Error(readspecies): apword <= 0 : ",I8)') apword(0,is)
     write(*,'(" for species ",I4)') is
     write(*,*)
     stop
   end if
-  if (apword(0,is).gt.maxapword) then
+  if (apword(0,is) > maxapword) then
     write(*,*)
     write(*,'("Error(readspecies): apword too large : ",I8)') apword(0,is)
     write(*,'(" for species ",I4)') is
@@ -122,7 +122,7 @@ do is=1,nspecies
   apword(1:lmaxapw,is)=apword(0,is)
   do io=1,apword(0,is)
     read(50,*) apwe0(io,0,is),apwdm(io,0,is),apwve(io,0,is)
-    if (apwdm(io,0,is).lt.0) then
+    if (apwdm(io,0,is) < 0) then
       write(*,*)
       write(*,'("Error(readspecies): apwdm < 0 : ",I8)') apwdm(io,0,is)
       write(*,'(" for species ",I4)') is
@@ -137,7 +137,7 @@ do is=1,nspecies
     e0min=min(e0min,apwe0(io,0,is))
   end do
   read(50,*) nlx
-  if (nlx.lt.0) then
+  if (nlx < 0) then
     write(*,*)
     write(*,'("Error(readspecies): nlx < 0 : ",I8)') nlx
     write(*,'(" for species ",I4)') is
@@ -146,7 +146,7 @@ do is=1,nspecies
   end if
   do ilx=1,nlx
     read(50,*) lx,io
-    if (lx.lt.0) then
+    if (lx < 0) then
       write(*,*)
       write(*,'("Error(readspecies): lx < 0 : ",I8)') lx
       write(*,'(" for species ",I4)') is
@@ -154,7 +154,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (lx.gt.lmaxapw) then
+    if (lx > lmaxapw) then
       write(*,*)
       write(*,'("Error(readspecies): lx > lmaxapw : ",I8)') lx
       write(*,'(" for species ",I4)') is
@@ -163,7 +163,7 @@ do is=1,nspecies
       stop
     end if
     apword(lx,is)=io
-    if (apword(lx,is).le.0) then
+    if (apword(lx,is) <= 0) then
       write(*,*)
       write(*,'("Error(readspecies): apword <= 0 : ",I8)') apword(lx,is)
       write(*,'(" for species ",I4)') is
@@ -171,7 +171,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (apword(lx,is).gt.maxapword) then
+    if (apword(lx,is) > maxapword) then
       write(*,*)
       write(*,'("Error(readspecies): apword too large : ",I8)') apword(lx,is)
       write(*,'(" for species ",I4)') is
@@ -182,7 +182,7 @@ do is=1,nspecies
     end if
     do io=1,apword(lx,is)
       read(50,*) apwe0(io,lx,is),apwdm(io,lx,is),apwve(io,lx,is)
-      if (apwdm(io,lx,is).lt.0) then
+      if (apwdm(io,lx,is) < 0) then
         write(*,*)
         write(*,'("Error(readspecies): apwdm < 0 : ",I8)') apwdm(io,lx,is)
         write(*,'(" for species ",I4)') is
@@ -195,11 +195,11 @@ do is=1,nspecies
     end do
   end do
 ! add excess order to APW functions if required
-  if (nxoapwlo.gt.0) then
+  if (nxoapwlo > 0) then
     do l=0,lmaxapw
       jo=apword(l,is)
       ko=jo+nxoapwlo
-      if (ko.gt.maxapword) ko=maxapword
+      if (ko > maxapword) ko=maxapword
       i=0
       do io=jo+1,ko
         i=i+1
@@ -211,14 +211,14 @@ do is=1,nspecies
     end do
   end if
   read(50,*) nlorb(is)
-  if (nlorb(is).lt.0) then
+  if (nlorb(is) < 0) then
     write(*,*)
     write(*,'("Error(readspecies): nlorb < 0 : ",I8)') nlorb(is)
     write(*,'(" for species ",I4)') is
     write(*,*)
     stop
   end if
-  if (nlorb(is).gt.maxlorb) then
+  if (nlorb(is) > maxlorb) then
     write(*,*)
     write(*,'("Error(readspecies): nlorb too large : ",I8)') nlorb(is)
     write(*,'(" for species ",I4)') is
@@ -228,7 +228,7 @@ do is=1,nspecies
   end if
   do ilo=1,nlorb(is)
     read(50,*) lorbl(ilo,is),lorbord(ilo,is)
-    if (lorbl(ilo,is).lt.0) then
+    if (lorbl(ilo,is) < 0) then
       write(*,*)
       write(*,'("Error(readspecies): lorbl < 0 : ",I8)') lorbl(ilo,is)
       write(*,'(" for species ",I4)') is
@@ -236,7 +236,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (lorbl(ilo,is).gt.lmaxo) then
+    if (lorbl(ilo,is) > lmaxo) then
       write(*,*)
       write(*,'("Error(readspecies): lorbl > lmaxo : ",2I8)') lorbl(ilo,is), &
        lmaxo
@@ -245,7 +245,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (lorbord(ilo,is).lt.2) then
+    if (lorbord(ilo,is) < 2) then
       write(*,*)
       write(*,'("Error(readspecies): lorbord < 2 : ",I8)') lorbord(ilo,is)
       write(*,'(" for species ",I4)') is
@@ -253,7 +253,7 @@ do is=1,nspecies
       write(*,*)
       stop
     end if
-    if (lorbord(ilo,is).gt.maxlorbord) then
+    if (lorbord(ilo,is) > maxlorbord) then
       write(*,*)
       write(*,'("Error(readspecies): lorbord too large : ",I8)') lorbord(ilo,is)
       write(*,'(" for species ",I4)') is
@@ -264,7 +264,7 @@ do is=1,nspecies
     end if
     do io=1,lorbord(ilo,is)
       read(50,*) lorbe0(io,ilo,is),lorbdm(io,ilo,is),lorbve(io,ilo,is)
-      if (lorbdm(io,ilo,is).lt.0) then
+      if (lorbdm(io,ilo,is) < 0) then
         write(*,*)
         write(*,'("Error(readspecies): lorbdm < 0 : ",I8)') lorbdm(io,ilo,is)
         write(*,'(" for species ",I4)') is
@@ -277,20 +277,20 @@ do is=1,nspecies
     end do
   end do
 ! add excess local-orbitals if required
-  if (nxlo.gt.0) then
+  if (nxlo > 0) then
     lx=-1
     do ilo=1,nlorb(is)
       do io=1,lorbord(ilo,is)
-        if (lorbe0(io,ilo,is).lt.0.d0) goto 10
+        if (lorbe0(io,ilo,is) < 0.d0) goto 10
       end do
-      if (lorbl(ilo,is).gt.lx) lx=lorbl(ilo,is)
+      if (lorbl(ilo,is) > lx) lx=lorbl(ilo,is)
 10 continue
     end do
     ilo=nlorb(is)
     do i=1,nxlo
-      if (ilo.eq.maxlorb) exit
+      if (ilo == maxlorb) exit
       l=lx+i
-      if (l.gt.lmaxo) exit
+      if (l > lmaxo) exit
       ilo=ilo+1
       lorbl(ilo,is)=l
       lorbord(ilo,is)=apword(l,is)+1
@@ -303,20 +303,20 @@ do is=1,nspecies
     nlorb(is)=ilo
   end if
 ! add excess order to local-orbitals if required
-  if (nxoapwlo.gt.0) then
+  if (nxoapwlo > 0) then
     do ilo=1,nlorb(is)
 ! find the maximum energy derivative
       jo=1
       j=lorbdm(jo,ilo,is)
       do io=1,lorbord(ilo,is)
         i=lorbdm(io,ilo,is)
-        if (i.gt.j) then
+        if (i > j) then
           jo=io
           j=i
         end if
       end do
       ko=lorbord(ilo,is)+nxoapwlo
-      if (ko.gt.maxlorbord) ko=maxlorbord
+      if (ko > maxlorbord) ko=maxlorbord
       i=0
       do io=lorbord(ilo,is)+1,ko
         i=i+1
@@ -330,9 +330,11 @@ do is=1,nspecies
   close(50)
 end do
 ! set all muffin-tin radii to single value if required
-if (rmtall.gt.0.d0) rmt(1:nspecies)=rmtall
+if (rmtall > 0.d0) rmt(1:nspecies)=rmtall
+! make a copy of the muffin-tin radii
+rmt0(1:nspecies)=rmt(1:nspecies)
 ! add conduction state local-orbitals if required
-call addlorbcnd
+if (lorbcnd) call addlorbcnd
 ! subtract 2 Hartree from the minimum energy
 e0min=e0min-2.d0
 end subroutine
