@@ -18,7 +18,7 @@ call init1
 ! read density and potentials from file
 call readstate
 ! use existing density if wsfac is default
-if ((wsfac(1).le.-1.d6).and.(wsfac(2).ge.1.d6)) goto 10
+if ((wsfac(1) <= -1.d6).and.(wsfac(2) >= 1.d6)) goto 10
 ! make a copy of the core state occupancies
 allocate(occcr0(nstspmax,natmtot))
 occcr0(:,:)=occcr(:,:)
@@ -27,7 +27,7 @@ do ias=1,natmtot
   is=idxis(ias)
   do ist=1,nstsp(is)
     if (spcore(ist,is)) then
-      if ((evalcr(ist,ias).lt.wsfac(1)).or.(evalcr(ist,ias).gt.wsfac(2))) then
+      if ((evalcr(ist,ias) < wsfac(1)).or.(evalcr(ist,ias) > wsfac(2))) then
         occcr(ist,ias)=0.d0
       end if
     end if
@@ -52,7 +52,7 @@ do ik=1,nkpt
   call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
 ! zero occupancies for eigenvalues not in energy window
   do ist=1,nstsv
-    if ((evalsv(ist,ik).lt.wsfac(1)).or.(evalsv(ist,ik).gt.wsfac(2))) then
+    if ((evalsv(ist,ik) < wsfac(1)).or.(evalsv(ist,ik) > wsfac(2))) then
       occsv(ist,ik)=0.d0
     end if
   end do
