@@ -27,17 +27,17 @@ call genapwfr
 ! generate the local-orbital radial functions
 call genlofr
 ! set the occupancies
-if ((task.eq.61).or.(task.eq.62).or.(task.eq.63)) then
+if ((task == 61).or.(task == 62).or.(task == 63)) then
 ! plot of wavefunction modulus squared
   ik=kstlist(1,1)
   ist=kstlist(2,1)
-  if ((ik.lt.1).or.(ik.gt.nkpt)) then
+  if ((ik < 1).or.(ik > nkpt)) then
     write(*,*)
     write(*,'("Error(wfplot): k-point out of range : ",I8)') ik
     write(*,*)
     stop
   end if
-  if ((ist.lt.1).or.(ist.gt.nstsv)) then
+  if ((ist < 1).or.(ist > nstsv)) then
     write(*,*)
     write(*,'("Error(wfplot): state out of range : ",I8)') ist
     write(*,*)
@@ -98,7 +98,7 @@ if (mp_mpi) then
     write(*,'("Info(wfplot):")')
     write(*,'(" 3D wavefunction modulus squared written to WF3D.OUT")')
   end select
-  if (task.ne.162) then
+  if (task /= 162) then
     write(*,'(" for k-point ",I8," and state ",I6)') kstlist(1,1),kstlist(2,1)
   end if
 end if
