@@ -8,6 +8,7 @@ use modmain
 use modpw
 use modmpi
 use modomp
+use moddelf
 implicit none
 ! local variables
 integer ik,ihk,recl
@@ -43,10 +44,7 @@ do ik=1,nkpt
   call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
 end do
 ! delete existing EMD.OUT
-if (mp_mpi) then
-  open(250,file='EMD.OUT')
-  close(250,status='DELETE')
-end if
+if (mp_mpi) call delfile('EMD.OUT')
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 allocate(emd(nhkmax))
@@ -63,7 +61,7 @@ allocate(emd(nhkmax),wfpw(nhkmax,nspinor,nstsv))
 !$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
-  if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+  if (mod(ik-1,np_mpi) /= lp_mpi) cycle
 !$OMP CRITICAL(writeemd_)
   write(*,'("Info(writeemd): ",I6," of ",I6," k-points")') ik,nkpt
 !$OMP END CRITICAL(writeemd_)
