@@ -34,7 +34,7 @@ do ik=1,nkpt
 end do
 ! check if system is metallic
 t1=minval(abs(0.5d0-occsv(:,:)/occmax))
-if (abs(t1-0.5d0).gt.0.01d0) then
+if (abs(t1-0.5d0) > 0.01d0) then
   write(*,*)
   write(*,'("Warning(writehmlbse): system is metallic, the BSE may fail")')
   write(*,'("Try using a different vkloff or reducing swidth")')
@@ -54,14 +54,14 @@ hmlbse(:,:)=0.d0
 ! compute diagonal matrix elements
 do ik=1,nkptnr
 ! distribute among MPI processes
-  if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
+  if (mod(ik-1,np_mpi) /= lp_mpi) cycle
   jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
   do i=1,nvbse
     ist=istbse(i,ik)
     do j=1,ncbse
       jst=jstbse(j,ik)
       a=ijkbse(i,j,ik)
-      hmlbse(a,a)=(evalsv(jst,jk)+scissor)-evalsv(ist,jk)
+      hmlbse(a,a)=evalsv(jst,jk)-evalsv(ist,jk)
       if (bsefull) then
         b=a+nbbse
         hmlbse(b,b)=-hmlbse(a,a)
@@ -74,7 +74,7 @@ if (hxbse) call hmlxbse
 ! add the direct matrix elements
 if (hdbse) call hmldbse
 ! add matrices from all processes and redistribute
-if (np_mpi.gt.1) then
+if (np_mpi > 1) then
 ! ensure that the number of elements transmitted by MPI is not larger than the
 ! maximum packet size (assumed to be 1024³ bytes)
   m=67108864/nmbse
