@@ -7,7 +7,7 @@ subroutine writetm
 use modmain
 use moddftu
 implicit none
-if (dftu.eq.0) then
+if (dftu == 0) then
   write(*,*)
   write(*,'("Error(writetmdu): dftu = 0")')
   write(*,*)
@@ -17,10 +17,12 @@ end if
 call init0
 ! read density matrix from file DMATMT.OUT
 call readdmatmt
+! generate the DFT+U muffin-tin potential matrices
+call genvmatmt
 ! write tensor moments to TENSMOM.OUT file
 call writetm3
 write(*,*)
-write(*,'("Info(writetm): Tensor moment decomposition of density matrix")')
+write(*,'("Info(writetm): tensor moment decomposition of density matrix")')
 write(*,'(" in the spherical basis written to TENSMOM.OUT")')
 end subroutine
 
